==> fgx_easy_log-0.0.1.tar.gz: lib/main/easylog.dart <==
// ignore_for_file: unnecessary_type_check

import 'package:facebook_app_events/facebook_app_events.dart';
import 'package:fl_umeng/fl_umeng.dart';

const String kEasyLogParamErrorCode     = "kEasyLogParamErrorCode";
const String kEasyLogParamErrorType     = "kEasyLogParamErrorType";
const String kEasyLogParamErrorDomain   = "kEasyLogParamErrorDomain";
const String kEasyLogParamErrorMessage  = "kEasyLogParamErrorMessage";
const String kEasyLogParamResult        = "kEasyLogParamResult";

class EasyLog {

  static void logEvent(String eventName) {
    EasyLogManager().event(eventName);
  }

  static void logEventWithParams(
      String eventName, Map<String, String> params) {
    EasyLogManager().event(eventName, attributes: params);
  }

  static void logEventWithParamAndValue(
    String eventName,
    String name,
    String value, {
    String? name1,
    String? value1,
    String? name2,
    String? value2,
    String? name3,
    String? value3,
    String? name4,
    String? value4,
    String? name5,
    String? value5,
  }) {
    Map<String, String> params = {};
    if(name is String && value is String) {
      params[name] = value;
    }
    if(name1 is String && value1 is String) {
      params[name1] = value1;
    }
    if(name2 is String && value2 is String) {
      params[name2] = value2;
    }
    if(name3 is String && value3 is String) {
      params[name3] = value3;
    }
    if(name4 is String && value4 is String) {
      params[name4] = value4;
    }
    if(name5 is String && value5 is String) {
      params[name5] = value5;
    }
    EasyLogManager().event(eventName, attributes: params);
  }

  static void calcEvent(String eventName, int number) {
    EasyLogManager().event(eventName, attributes: {}, number: number);
  }

  static void calcEventWithParams(
      String eventName, int number, Map<String, String> params) {
    EasyLogManager().event(eventName, attributes: params, number: number);
  }

  static void calcEventWithParamAndValue(
    String eventName,
    int number,
    String name,
    String value, {
    String? name1,
    String? value1,
    String? name2,
    String? value2,
    String? name3,
    String? value3,
    String? name4,
    String? value4,
    String? name5,
    String? value5,
  }) {
    Map<String, String> params = {};
    if(name is String && value is String) {
      params[name] = value;
    }
    if(name1 is String && value1 is String) {
      params[name1] = value1;
    }
    if(name2 is String && value2 is String) {
      params[name2] = value2;
    }
    if(name3 is String && value3 is String) {
      params[name3] = value3;
    }
    if(name4 is String && value4 is String) {
      params[name4] = value4;
    }
    if(name5 is String && value5 is String) {
      params[name5] = value5;
    }
    EasyLogManager().event(eventName, attributes: params, number: number);
  }
}

class EasyLogManager {

  EasyLogManager._internal();
  factory EasyLogManager() => _instance;
  static late final EasyLogManager _instance = EasyLogManager._internal();

  static final umengEvents = FlUMeng();
  static final facebookAppEvents = FacebookAppEvents();

  void event(String eventId, {
    Map<String, String>? attributes,
    int? number
  }) async {
    if(number is int) {
      facebookAppEvents.logEvent(name: eventId, valueToSum: number.toDouble());
      umengEvents.onEvent(eventId, {"number": number});
    }else if(attributes is Map) {
      facebookAppEvents.logEvent(name: eventId, parameters: attributes);
      umengEvents.onEvent(eventId, attributes!);
    }else {
      facebookAppEvents.logEvent(name: eventId);
      umengEvents.onEvent(eventId, {});
    }
  }
}

==> fgx_easy_log-0.0.2.tar.gz: lib/main/easylog.dart <==
// ignore_for_file: unnecessary_type_check, unused_import

import 'package:facebook_app_events/facebook_app_events.dart';
import 'package:umeng_common_sdk/umeng_common_sdk.dart';

const String kEasyLogParamErrorCode     = "kEasyLogParamErrorCode";
const String kEasyLogParamErrorType     = "kEasyLogParamErrorType";
const String kEasyLogParamErrorDomain   = "kEasyLogParamErrorDomain";
const String kEasyLogParamErrorMessage  = "kEasyLogParamErrorMessage";
const String kEasyLogParamResult        = "kEasyLogParamResult";

class EasyLog {

  static void logEvent(String eventName) {
    EasyLogManager().event(eventName);
  }

  static void logEventWithParams(
      String eventName, Map<String, String> params) {
    EasyLogManager().event(eventName, attributes: params);
  }

  static void logEventWithParamAndValue(
    String eventName,
    String name,
    String value, {
    String? name1,
    String? value1,
    String? name2,
    String? value2,
    String? name3,
    String? value3,
    String? name4,
    String? value4,
    String? name5,
    String? value5,
  }) {
    Map<String, String> params = {};
    if(name is String && value is String) {
      params[name] = value;
    }
    if(name1 is String && value1 is String) {
      params[name1] = value1;
    }
    if(name2 is String && value2 is String) {
      params[name2] = value2;
    }
    if(name3 is String && value3 is String) {
      params[name3] = value3;
    }
    if(name4 is String && value4 is String) {
      params[name4] = value4;
    }
    if(name5 is String && value5 is String) {
      params[name5] = value5;
    }
    EasyLogManager().event(eventName, attributes: params);
  }

  static void calcEvent(String eventName, int number) {
    EasyLogManager().event(eventName, attributes: {}, number: number);
  }

  static void calcEventWithParams(
      String eventName, int number, Map<String, String> params) {
    EasyLogManager().event(eventName, attributes: params, number: number);
  }

  static void calcEventWithParamAndValue(
    String eventName,
    int number,
    String name,
    String value, {
    String? name1,
    String? value1,
    String? name2,
    String? value2,
    String? name3,
    String? value3,
    String? name4,
    String? value4,
    String? name5,
    String? value5,
  }) {
    Map<String, String> params = {};
    if(name is String && value is String) {
      params[name] = value;
    }
    if(name1 is String && value1 is String) {
      params[name1] = value1;
    }
    if(name2 is String && value2 is String) {
      params[name2] = value2;
    }
    if(name3 is String && value3 is String) {
      params[name3] = value3;
    }
    if(name4 is String && value4 is String) {
      params[name4] = value4;
    }
    if(name5 is String && value5 is String) {
      params[name5] = value5;
    }
    EasyLogManager().event(eventName, attributes: params, number: number);
  }
}

class EasyLogManager {

  EasyLogManager._internal();
  factory EasyLogManager() => _instance;
  static late final EasyLogManager _instance = EasyLogManager._internal();

  static final facebookAppEvents = FacebookAppEvents();

  void event(String eventId, {
    Map<String, String>? attributes,
    int? number
  }) async {
    if(number is int) {
      facebookAppEvents.logEvent(name: eventId, valueToSum: number.toDouble());
      UmengCommonSdk.onEvent(eventId, {"number": number});
    }else if(attributes is Map) {
      facebookAppEvents.logEvent(name: eventId, parameters: attributes);
      UmengCommonSdk.onEvent(eventId, attributes!);
    }else {
      facebookAppEvents.logEvent(name: eventId);
      UmengCommonSdk.onEvent(eventId, {});
    }
  }
}
